@@ -197,9 +197,6 @@ def get_apps_config() -> Dict:
     Returns:
         Dict: dictionnary of {app: {dir:_,status:_}}
     """
-    if not APPS_PATH.is_file():
-        raise AppsNotFoundError
-
     with open(APPS_PATH, "r") as apps_file:
         data = yaml.load(apps_file, Loader=yaml.SafeLoader)
         data = {} if data is None else data
@@ -254,7 +251,7 @@ def check_app_exist(app_name: str) -> Tuple[bool, Union[str, None]]:
     Returns:
         Tuple[bool, str]: return is the app exist and Filename
     """
-    root_path = _create_deechpain_folder()
+    root_path = ensure_has_config_folder()
     _ = _create_apps_file(root_path)
 
     config = get_apps_config()
@@ -275,7 +272,7 @@ def save_app(app_name: str, dest_path: str) -> None:
         app_name (str): application name stored in .deepchain/apps
         dest_path (str): folder for registraction of the app
     """
-    root_path = _create_deechpain_folder()
+    root_path = ensure_has_config_folder()
     path = _create_apps_file(root_path)
     data = get_apps_config()
 
@@ -354,14 +351,14 @@ def save_configuration(key: str, val: str):
         yaml.dump(data, config_file)
 
 
-def _create_deechpain_folder() -> Path:
+def ensure_has_config_folder() -> Path:
     """create .deepchain folder if not exist"""
     path = Path.home().joinpath(".deep-chain")
     path.mkdir(exist_ok=True)
     return path
 
 
-def _create_config_file(root_path: Path) -> Path:
+def ensure_has_config_file(root_path: Path) -> Path:
     """
     create the config file to store the personal access token
     """
