@@ -11,6 +11,8 @@ from typing import Any, Dict, List
 import pkg_resources
 import requests
 from deepchain import log
+from tqdm import tqdm
+from tqdm.utils import CallbackIOWrapper
 
 
 def upload_code(
@@ -85,16 +87,23 @@ def upload_checkpoint(app_dir: str, app_name: str, pat: str, url: str, size_limi
         "tar",
         app_dir + "/checkpoint",
     )
-    if os.stat(archive).st_size / (1024 * 1024) > size_limit:
+    file_size = os.stat(archive).st_size
+    desc = "uploading checkpoint"
+    if file_size / (1024 * 1024) > size_limit:
         log.critical(f"Can not upload files over {size_limit}MB")
         log.warning("Checkpoint not uploaded.")
         return
     else:
-        req = requests.put(
-            signed_url,  # type: ignore
-            data=open(archive, "rb").read(),
-            headers={"Content-Type": "application/octet-stream"},
-        )
+        with open(archive, "rb") as f:
+            with tqdm(
+                total=file_size, unit="B", unit_scale=True, unit_divisor=1024, desc=desc
+            ) as t:
+                wrapped_file = CallbackIOWrapper(t.update, f, "read")
+                req = requests.put(
+                    signed_url,  # type: ignore
+                    data=wrapped_file,
+                    headers={"Content-Type": "application/octet-stream"},
+                )
         if req.status_code != 200:
             log.warning("api return %s stopping operation", req.status_code)
             log.warning("Checkpoint not uploaded.")
