@@ -3,10 +3,13 @@
 #!/usr/bin/python3 # noqa: E265
 import argparse
 
+from deepchain.cli.set_backend import SetBackendCommand
+
 from .apps import AppsCommand
 from .auth import AuthCommand
 from .deploy import DeployCommand
-from .download import DownloadCommmand
+from .download import DownloadCommand
+from .config import ConfigCommand
 
 # from .inference import InferenceCommand
 from .scaffold import CreateCommand
@@ -24,7 +27,9 @@ def main():
     CreateCommand.register_subcommand(commands_parser)
     DeployCommand.register_subcommand(commands_parser)
     AppsCommand.register_subcommand(commands_parser)
-    DownloadCommmand.register_subcommand(commands_parser)
+    DownloadCommand.register_subcommand(commands_parser)
+    ConfigCommand.register_subcommand(commands_parser)
+    SetBackendCommand.register_subcommand(commands_parser)
     # InferenceCommand.register_subcommand(commands_parser)
 
     args = parser.parse_args()
