@@ -34,8 +34,14 @@ class AppsNotFoundError(DeepChainAppException):
 
 
 class CheckpointNotFoundError(DeepChainAppException):
-    def __init__(self, checkpoint_format):
+    def __init__(self):
         super(CheckpointNotFoundError, self).__init__(
-            f"Don't find any checkpoint format like {' - '.join(checkpoint_format)} "
-            "in checkpoint folder"
+            "Don't find any checkpoint file in checkpoint folder"
+        )
+
+
+class InvalidAppName(DeepChainAppException):
+    def __init__(self, invalid_char):
+        super(InvalidAppName, self).__init__(
+            f"Your app' name must not contain the invalid character {invalid_char}"
         )
